@@ -1,4 +1,8 @@
 #  -*- coding: utf-8 -*-
+import os
+import sys
+
+sys.path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../../")
 from volcengine.example.cdn import ak, sk
 from volcengine.cdn.service import CDNService
 
